@@ -294,9 +294,9 @@ class Update:
                 print(f'   + {login}')
                 try:
                     self.github.invite_org_member(login)
-                except Exception as e:
+                except Exception as exc:
                     print(f'ERROR: Failed to invite org member: {login}')
-                    print(e)
+                    print(exc)
 
         if remove:
             print(f'\nMembers to remove: {len(remove)}')
@@ -435,9 +435,13 @@ class Update:
             del sync['_id']
             email = sync['google_group']
 
-            print(f'Getting group and members: {email}')
             # get group
-            group = g.directory().get_group(email)
+            try:
+                group = g.directory().get_group(email)
+            except Exception:
+                print(f'Group does not exist or is inaccessible: {email}')
+                continue
+            print(f'Getting group and members: {email}')
             # get members
             members = []
             for m in g.directory().get_members_recursively(email):
